.. _changelog:

=========
CHANGELOG
=========


.. _changelog-v0.0.1:

v0.0.1 (2025-02-18)
===================

Bug Fixes
---------

* fix: edit description (`9dd8873`_)

Unknown
-------

* init project (`89a4278`_)

* Initial commit (`88ede42`_)

.. _9dd8873: https://github.com/starccato/starccato_sampler/commit/9dd88736b267e275cfe9f65d937bc693863eb1b9
.. _89a4278: https://github.com/starccato/starccato_sampler/commit/89a42788db798a39075879c91220dbb653c272cd
.. _88ede42: https://github.com/starccato/starccato_sampler/commit/88ede4295f39fa76d4d8782404cb2855f71bb4de
